(es-date-histogram! es-uri
index
interval
start
end
timezone
criteria
field-list)Returns a date histogram based on params:
interval hour | day | week | month | year,
start a local date - for example 2017-05-04
end local date
timezone for example Australia/Sydney
criteria a key value map of field critera to search by.
field-list a keyword/string list of field names to aggregate.
Returns a date histogram based on params: `interval` hour | day | week | month | year, `start` a local date - for example `2017-05-04` `end` local date `timezone` for example `Australia/Sydney` `criteria` a key value map of field critera to search by. `field-list` a keyword/string list of field names to aggregate.
(es-delete-by-query! es-uri index criteria)Deletes docs from elasticsearch based on criteria.
criteria is a map with multiple field = match-value search criteria.
Deletes docs from elasticsearch based on `criteria`. `criteria` is a map with multiple `field = match-value` search criteria.
(es-parse-histogram-result es-result field-list)Extracts the required values from elasticsearch result and converts to a simple flat array.
Extracts the required values from elasticsearch result and converts to a simple flat array.
(es-post-bulk! es-uri index data)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |